# Lensi

## 使用教程
### 简介

+ Lensi安装`pip install lensi`
+ Lensi CLI为360 qq scoop choco winget hippo的聚合命令行工具。

+ 主要命令

       clean(清楚Download缓存)
       download(只下载文件，并打开文件夹)
       info(显示软件的详细信息)
       init(消除整个lensi文件夹)
       install(正常安装软件)
       list(显示由lensi安装的软件)
       search(搜索功能，聚合搜索，主要功能)
       set(一些设置)
       uninstall(卸载软件(软件是电脑中所有的软件都可以))

+ 各个命令具体参数使用help可查看
+ search返回样式：
+ 
+ 